//
//  Keyword+Helper.swift
//  SlipboxProject
//
//  Created by Karin Prater on 28.11.22.
//

import SwiftUI
import CoreData

extension Keyword {
    
    var name: String {
        get { name_ ?? "" }
        set { name_ = newValue }
    }
    
    var colorHex: Color {
        get {
            if let colorHexValue = colorHex_,
               let color = Color(hex: colorHexValue) {
               return color
            } else {
               return Color.black
            }
        }
        set {
           colorHex_ = newValue.toHex()
        }
    }
    
    
    var color: Color {
        get {
            Color(red: red_, green: green_, blue: blue_, opacity: opacity_)
        }
        set {
            guard let components = newValue.cgColor?.components,
                    components.count > 2 else { return }
            
            red_ = components[0]
            green_ = components[1]
            blue_ = components[2]
            
            if components.count == 4 {
                opacity_ = components[3]
            } else {
                opacity_ = 1
            }
        }
    }
    
    var notes: Set<Note> {
        get { (notes_ as? Set<Note>) ?? [] }
        set { notes_ = newValue as NSSet }
    }
    
    convenience init(name: String, context: NSManagedObjectContext) {
        self.init(context: context)
        self.name = name
    }
    
    static func fetch(_ predicate: NSPredicate = .all) -> NSFetchRequest<Keyword> {
        let request = Keyword.fetchRequest()
         request.sortDescriptors = [NSSortDescriptor(keyPath: \Keyword.name_, ascending: true)]
         request.predicate = predicate
         
         return request
     }
    
    static func fetch(for note: Note) -> NSFetchRequest<Keyword> {
        let predicate = NSPredicate(format: "%K CONTAINS %@", KeywordProperties.notes, note)
        return Keyword.fetch(predicate)
    }
    
    //MARK: - Preview Helper
    
    static func exampleArray() -> [Keyword] {
        let context = PersistenceController.preview.container.viewContext
        
        var keys = [Keyword]()
        for index in 0...4 {
            let key = Keyword(name: "keyword \(index)", context: context)
            let colorValue = CGFloat(index) / 5
            key.color = Color(red: colorValue , green: 0.5, blue: colorValue)
            keys.append(key)
        }
        
        return keys
    }
}


//MARK: - define my string constants

struct KeywordProperties {
    static let name = "name_"
    static let notes = "notes_"
}
