//
//  FolderRow.swift
//  SlipboxProject
//
//  Created by Karin Prater on 29.11.22.
//

import SwiftUI

struct FolderRow: View {
    
    @Environment(\.managedObjectContext) var viewContext
    @ObservedObject var folder: Folder
    
    @State private var showRenameEditor: Bool = false
    @State private var showDeleteConfirmation: Bool = false
    @FocusState private var textFieldIsSelected: Bool
    
    var body: some View {
        Group {
            #if os(iOS)
            Text(folder.name)
            #else
            TextField("name", text: $folder.name)
                .focused($textFieldIsSelected)
            
            #endif
        }
            .contextMenu {
                
                Button("Rename") {
                 startRenameAction()
                }
                
                Button {
                    let subfolder = Folder(name: "new subfolder", context: viewContext)
                    folder.children.insert(subfolder)
                } label: {
                    Text("Create New Subfolder")
                }
                
                Divider()
                
                Button("Delete") {
                   showDeleteConfirmation = true
                }
            }
            .confirmationDialog("Delete", isPresented: $showDeleteConfirmation) {
                Button("Delete") {
                    Folder.delete(folder)
                }
            }
            .sheet(isPresented: $showRenameEditor) {
                FolderEditorView(folder: folder)
            }
    }
    
    func startRenameAction() {
        #if os(OSX)
        textFieldIsSelected = true
        #else
        showRenameEditor = true
        #endif
    }
}

struct FolderRow_Previews: PreviewProvider {
    static var previews: some View {
        FolderRow(folder: Folder(name: "new", context: PersistenceController.preview.container.viewContext))
        
            .frame(width: 200)
            .padding(50)
    }
}
