//
//  AddKeywordsToNoteView.swift
//  SlipboxProject
//
//  Created by Karin Prater on 09.12.22.
//

import SwiftUI

struct AddKeywordsToNoteView: View {
    
    let note: Note
    
    @State private var searchTerm: String = ""
    @FetchRequest(fetchRequest: Keyword.fetch(.all)) var keywords
    
    @State private var selectedKeywords = Set<Keyword>()
    
    @Environment(\.managedObjectContext) var context
    @Environment(\.dismiss) var dismiss
    
    var body: some View {
        VStack {
            HStack(spacing: 0) {
                Text("Add keywords to ")
                Text(note.title).bold()
            }
            
            HStack {
                TextField("search", text: $searchTerm)
                    .textFieldStyle(.roundedBorder)
                
                if searchTerm.count > 0 {
                    Button {
                        searchTerm = ""
                    } label: {
                        Text("clear")
                    }
                    .foregroundColor(.pink)
                }
            }
                
            List(selection: $selectedKeywords) {
                ForEach(keywords) { keyword in
                    
                    HStack {
                        Image(systemName: "tag.fill")
                            .foregroundColor(keyword.color)
                        Text(keyword.name)
                    }
                    .tag(keyword)
                }
            }
            .listStyle(.plain)
            .frame(minHeight: 150)
            
            if selectedKeywords.count > 0 {
                Button {
                    selectedKeywords.forEach { key in
                        note.keywords.insert(key)
                    }
                    dismiss()
                } label: {
                    Text("Add keywords to note")
                }
            } else if keywords.count == 0 {
                
               NewKeywordView(note: note,
                              searchTerm: searchTerm)
            }
        
        }
        .padding()
        .onChange(of: searchTerm) { newValue in
            
            if newValue.count > 0 {
                keywords.nsPredicate = NSPredicate(format: "%K CONTAINS[cd] %@",KeywordProperties.name , searchTerm as CVarArg)
            } else {
                keywords.nsPredicate = nil
            }
        }
    }
}

struct AddKeywordsToNoteView_Previews: PreviewProvider {
    static var previews: some View {
        AddKeywordsToNoteView(note: Note.example())
            .environment(\.managedObjectContext, PersistenceController.preview.container.viewContext)
    }
}
