//
//  NoteDetailView.swift
//  SlipboxProject
//
//  Created by Karin Prater on 19.11.22.
//

import SwiftUI

struct NoteDetailView: View {
    
    @Environment(\.managedObjectContext) var context
    @ObservedObject var note: Note
    @State private var showKeywordView = false
    
    var body: some View {
    
        VStack(alignment: .leading, spacing: 20) {
          
          Text("order \(Int(note.order))")
            
            TextField("title", text: $note.title)
                .textFieldStyle(.roundedBorder)
                .font(.title)
                
            Picker(selection: $note.status) {
                ForEach(Status.allCases) { status in
                    Text(status.rawValue)
                        .tag(status)
                }
            } label: {
                Text("Note´s status")
            }
            .pickerStyle(.segmented)

            #if os(iOS)
                TextViewIOSWrapper(note: note)
            #else
                TextViewMacosWrapper(note: note)
            #endif

            NotesKeywordsCollectionView(note: note)
            
            //OptionalImageView(data: note.img)
            if let attachment = note.attachment {
                NoteAttachmentView(attachment: attachment)
            }
            
            NotePhotoSelectorButton(note: note)
            
        }
      .padding()
        
      .onDisappear {
          PersistenceController.shared.save()
      }
      .toolbar {
          ToolbarItem {
              Button {
                  showKeywordView.toggle()
              } label: {
                  Image(systemName: "tag")
              }
              .popover(isPresented: $showKeywordView) {
                  AddKeywordsToNoteView(note: note)
                      .environment(\.managedObjectContext, context)
              }
          }
      }
    }
}

struct NoteDetailView_Previews: PreviewProvider {
    static var previews: some View {
        let context = PersistenceController.preview.container.viewContext
    
        return NavigationView {
            NoteDetailView(note: Note.example())
        }
            .environment(\.managedObjectContext, context)
    }
}
