//
//  NotesKeywordsCollectionView.swift
//  SlipboxProject
//
//  Created by Karin Prater on 09.12.22.
//

import SwiftUI

struct NotesKeywordsCollectionView: View {
    
    init(note: Note) {
        self.note = note
        self._keywords = FetchRequest(fetchRequest: Keyword.fetch(for: note))
    }
    
    let note: Note
    
    @FetchRequest(fetchRequest: Keyword.fetch(.none)) var keywords
    
    var body: some View {
        FlowLayout(alignment: .leading, spacing: 2) {
            
            ForEach(keywords) { keyword in
                HStack {
                    Image(systemName: "tag.fill")
                        .foregroundColor(keyword.color)
                    Text(keyword.name)
                }
                    .padding(5)
                    .background(RoundedRectangle(cornerRadius: 5).fill(Color(white: 0.9)))
                    .contextMenu {
                        Button {
                            keyword.notes.remove(note)
                        } label: {
                            Text("Remove Keyword")
                        }

                        Button {
                            // open new window with keyword and notes
                        } label: {
                            Text("Show notes for keyword")
                        }
                    }
                
            }
        }
    }
}


struct NotesKeywordsCollectionView_Previews: PreviewProvider {
    static var previews: some View {
        NotesKeywordsCollectionView(note: Note.example())
            .environment(\.managedObjectContext, PersistenceController.preview.container.viewContext)
    }
}

