//
//  FolderTests.swift
//  SlipboxProjectTests
//
//  Created by Karin Prater on 29.11.22.
//

import XCTest
@testable import SlipboxProject
import CoreData

final class FolderTests: XCTestCase {

    var controller: PersistenceController!
    
    var context: NSManagedObjectContext {
        controller.container.viewContext
    }

    override func setUpWithError() throws {
        self.controller = PersistenceController.createEmpty()
    }

    override func tearDownWithError() throws {
        self.controller = nil
    }

    func test_Folder_creationDate() {
        let folder = Folder(name: "new", context: context)
        
        XCTAssertNotNil(folder.creationDate_, "folder should have creation date")
    }
    
    func test_fetch_all_folders() {
        
        let folder1 = Folder(name: "first", context: context)
        let folder2 = Folder(name: "second", context: context)
        
        let request = Folder.fetch(.all)
        
        let retrievedFolders = try? context.fetch(request)
        
        XCTAssertNotNil(retrievedFolders)
        XCTAssertTrue(retrievedFolders?.count == 2, "should retrieve 2 folders that where added to database")
        XCTAssertTrue(retrievedFolders!.contains(folder1))
        XCTAssertTrue(retrievedFolders!.contains(folder2))
        
        XCTAssertTrue(retrievedFolders?.first == folder1)
        XCTAssertTrue(retrievedFolders?.last == folder2)
        
    }
    
    func test_top_folder_fetch()  {
        
        let parent = Folder(name: "parent", context: context)
        let child = Folder(name: "", context: context)
        parent.children.insert(child)
        
        let fetchRequest = Folder.topFolderFetch()
        let retrievedFolders = try! context.fetch(fetchRequest)
     
        XCTAssertTrue(retrievedFolders.count == 1)
        XCTAssertTrue(retrievedFolders.contains(parent))
        
    }
    
    func test_fetch_first_2_folders() {
        
        _ = Folder(name: "parent", context: context)
        _ = Folder(name: "parent", context: context)
        _ = Folder(name: "parent", context: context)
        
        let fetchRequest = Folder.topFolderFetch()
        fetchRequest.fetchLimit = 2
        
        let retrievedFolders = try! context.fetch(fetchRequest)
     
        XCTAssertTrue(retrievedFolders.count == 2)
        
    }
    
    func test_batch_size() {
        _ = Folder(name: "parent", context: context)
        _ = Folder(name: "parent", context: context)
        _ = Folder(name: "parent", context: context)
        
        let fetchRequest = Folder.topFolderFetch()
        fetchRequest.fetchBatchSize = 2
        
        let retrievedFolders = try! context.fetch(fetchRequest)
     
        XCTAssertTrue(retrievedFolders.count == 3)
    }
    
    func test_fetch_count_top_folders() {
        _ = Folder(name: "parent", context: context)
        _ = Folder(name: "parent", context: context)
        _ = Folder(name: "parent", context: context)
        
        let fetchRequest = Folder.topFolderFetch()
        fetchRequest.resultType = .countResultType
        
        let retrievedFoldersCount = try! context.count(for: fetchRequest)
        XCTAssertTrue(retrievedFoldersCount == 3)
    }
}
