//
//  KeywordTests.swift
//  SlipboxProjectTests
//
//  Created by Karin Prater on 28.11.22.
//

import XCTest
@testable import SlipboxProject
import SwiftUI
import CoreData

final class KeywordTests: XCTestCase {

    
    var controller: PersistenceController!
    
    var context: NSManagedObjectContext {
        controller.container.viewContext
    }

    override func setUpWithError() throws {
        self.controller = PersistenceController.createEmpty()
    }

    override func tearDownWithError() throws {
        self.controller = nil
    }

    
    func test_Keyword_hex_color() {
        
        let color = Color(red: 0, green: 0, blue: 1)
        let keyword = Keyword(context: context)
        keyword.colorHex = color
        
        let retrievedColor = keyword.colorHex
        
        XCTAssertTrue(retrievedColor == color)
        
    }
    
    func test_Keyword_default_color() {
        
        let black = Color.black
        let keyword = Keyword(context: context)
        let defaultColor = keyword.color
        
        XCTAssertTrue(defaultColor == black)
    }
    
    func test_Keyword_component_Color() {
        
        let color = Color(red: 0, green: 0, blue: 1)
        let keyword = Keyword(context: context)
        keyword.color = color
        
        let retrievedColor = keyword.color
        
        XCTAssertTrue(retrievedColor == color)
    }
    
    func test_search_keywords_for_note() {
        let keyword = Keyword(context: context)
        let note1 = Note(title: "dd", context: context)
        note1.keywords.insert(keyword)
        
        let request = Keyword.fetch(for: note1)
        let retrievedKeywords = try! context.fetch(request)
        
        XCTAssertTrue(retrievedKeywords.count == 1)
        XCTAssertTrue(retrievedKeywords.contains(keyword))
    }
    
    
}
